==> fact_schemas-1.0.3.tar.gz: lib/mixins/fact_schemas.dart <==
import 'package:fact_schemas/fact_schemas.dart';
import 'package:sunny_dart/sunny_dart.dart';
import 'package:sunny_sdk_core/model_exports.dart';
import 'package:sunny_service_stubs/models/facts/model/organization.dart';
import 'package:sunny_service_stubs/models/facts/model/task_fact.dart';
import 'package:sunny_service_stubs/models/m_entity/model/m_entity_definition.dart';

import '../fact_schemas.dart';

export 'fact_schema_mixin.dart';

mixin FactSchemaMixin implements IFactSchema {
  String? get pluralLabel => label?.pluralize(2);

  String? get id => "$ref";

  IFactSchemaTemplate? get pastTemplate => templates!["${IFactTense.past_}"];

  IFactSchemaTemplate? get presentTemplate =>
      templates!["${IFactTense.present_}"];

  IFactSchemaTemplate? get futureTemplate =>
      templates!["${IFactTense.future_}"];

  IFactSchemaTemplate? get defaultTemplate =>
      firstNonNull(presentTemplate, pastTemplate, futureTemplate);

  String? get label => defaultTemplate?.label;

  String? get title => defaultTemplate?.title;

  String? get template => defaultTemplate?.template;

  bool get isNotSingleton => isSingleton != true;

  Set<String> tokenize() => [
        ...?factTokens,
        label,
        template,
      ].map((e) => e.isNotNullOrBlank).toSet().cast<String>();

  bool get isDue => this is ITaskFact;

  bool get isActionable => dates?.any((date) => date.isActionable) == true;

  bool get isHistorical =>
      dates?.any((date) => date.isHistorical == true) == true;

  bool get isOrg {
    return this.parentRef == OrganizationRef;
  }

  MSchemaRef? get parentRef {
    return this.entitySchema.parentRef;
  }

  IMEntityDefinition get entitySchema {
    assert(this.mschema is IMEntityDefinition);
    return this.mschema as IMEntityDefinition;
  }

  bool get isTimeSensitive =>
      dates?.any((date) => date.isTimeSensitive) == true;

  JsonPath? get timelineField => dates
      .orEmptyList()
      .firstOrNull((date) => date.isHistorical == true)
      ?.path;

  IFactMetaDate? get firstHistoricalDate =>
      dates.orEmptyList().firstOrNull((date) => date.isHistorical == true);
}

mixin FactMetaDateMixin implements IFactMetaDate {
  Set<String> tokenize() => [...?dateTokens, remindLabel, label].notNullSet();

  String? get remindLabel => remindableInfo?.remindMeLabel;

  bool get isActionable => remindableInfo != null;
  bool get isRecurring =>
      !(recurs == null || recurs == IFactRecurrence.unknown_);
  bool get isTimeSensitive => timeSensitivity != null;
}

==> fact_schemas-1.0.5.tar.gz: lib/mixins/fact_schemas.dart <==
import 'package:fact_schemas/fact_schemas.dart';
import 'package:sunny_dart/sunny_dart.dart';
import 'package:sunny_sdk_core/model_exports.dart';
import 'package:sunny_service_stubs/models/facts/model/organization.dart';
import 'package:sunny_service_stubs/models/facts/model/task_fact.dart';
import 'package:sunny_service_stubs/models/m_entity/model/m_entity_definition.dart';

import '../fact_schemas.dart';

export 'fact_schema_mixin.dart';

mixin FactSchemaMixin implements IFactSchema {
  String? get pluralLabel => label?.pluralize(2);

  String? get id => "$ref";

  IFactSchemaTemplate? get pastTemplate => templates!["${IFactTense.past_}"];

  IFactSchemaTemplate? get presentTemplate =>
      templates!["${IFactTense.present_}"];

  IFactSchemaTemplate? get futureTemplate =>
      templates!["${IFactTense.future_}"];

  IFactSchemaTemplate? get defaultTemplate =>
      firstNonNull(presentTemplate, pastTemplate, futureTemplate);

  String? get label => defaultTemplate?.label;

  String? get title => defaultTemplate?.title;

  String? get template => defaultTemplate?.template;

  bool get isNotSingleton => isSingleton != true;

  Set<String> tokenize() => [
        ...?factTokens,
        label,
        template,
      ].where((e) => e.isNotNullOrBlank).toSet().cast<String>();

  bool get isDue => this is ITaskFact;

  bool get isActionable => dates?.any((date) => date.isActionable) == true;

  bool get isHistorical =>
      dates?.any((date) => date.isHistorical == true) == true;

  bool get isOrg {
    return this.parentRef == OrganizationRef;
  }

  MSchemaRef? get parentRef {
    return this.entitySchema.parentRef;
  }

  IMEntityDefinition get entitySchema {
    assert(this.mschema is IMEntityDefinition);
    return this.mschema as IMEntityDefinition;
  }

  bool get isTimeSensitive =>
      dates?.any((date) => date.isTimeSensitive) == true;

  JsonPath? get timelineField => dates
      .orEmptyList()
      .firstOrNull((date) => date.isHistorical == true)
      ?.path;

  IFactMetaDate? get firstHistoricalDate =>
      dates.orEmptyList().firstOrNull((date) => date.isHistorical == true);
}

mixin FactMetaDateMixin implements IFactMetaDate {
  Set<String> tokenize() => [...?dateTokens, remindLabel, label].notNullSet();

  String? get remindLabel => remindableInfo?.remindMeLabel;

  bool get isActionable => remindableInfo != null;
  bool get isRecurring =>
      !(recurs == null || recurs == IFactRecurrence.unknown_);
  bool get isTimeSensitive => timeSensitivity != null;
}
